summaryrefslogtreecommitdiff
path: root/libpod/container.go
diff options
context:
space:
mode:
authorMatthew Heon <matthew.heon@pm.me>2019-01-07 14:20:04 -0500
committerMatthew Heon <matthew.heon@pm.me>2019-01-07 14:37:51 -0500
commit5ed23327a9e68219f6d1eaf38e0533e732438eb5 (patch)
tree58e80f2f5cf336d5010d77b3071940a5145bca84 /libpod/container.go
parent148b4920dc9d866ce60654498af6e6bbc1d72f09 (diff)
downloadpodman-5ed23327a9e68219f6d1eaf38e0533e732438eb5.tar.gz
podman-5ed23327a9e68219f6d1eaf38e0533e732438eb5.tar.bz2
podman-5ed23327a9e68219f6d1eaf38e0533e732438eb5.zip
Rename libpod.Config back to ContainerConfig
During an earlier bugfix, we swapped all instances of ContainerConfig to Config, which was meant to fix some data we were returning from Inspect. This unfortunately also renamed a libpod internal struct for container configs. Undo the rename here. Signed-off-by: Matthew Heon <matthew.heon@pm.me>
Diffstat (limited to 'libpod/container.go')
-rw-r--r--libpod/container.go10
1 files changed, 5 insertions, 5 deletions
diff --git a/libpod/container.go b/libpod/container.go
index 4e5088b32..44992c534 100644
--- a/libpod/container.go
+++ b/libpod/container.go
@@ -113,7 +113,7 @@ func (ns LinuxNS) String() string {
// syncContainer() immediately after locking.
// ffjson: skip
type Container struct {
- config *Config
+ config *ContainerConfig
state *containerState
@@ -200,11 +200,11 @@ type ExecSession struct {
PID int `json:"pid"`
}
// Config contains all information that was used to create the
// container. It may not be changed once created.
// It is stored, read-only, on disk
// easyjson:json
-type Config struct {
+type ContainerConfig struct {
Spec *spec.Spec `json:"spec"`
ID string `json:"id"`
Name string `json:"name"`
@@ -385,8 +385,8 @@ func (t ContainerStatus) String() string {
// Unlocked
// Config returns the configuration used to create the container
-func (c *Container) Config() *Config {
- returnConfig := new(Config)
+func (c *Container) Config() *ContainerConfig {
+ returnConfig := new(ContainerConfig)
deepcopier.Copy(c.config).To(returnConfig)
return returnConfig
@@ -200,11 +200,11 @@ type ExecSession struct {
PID int `json:"pid"`
}
-// Config contains all information that was used to create the
+// ContainerConfig contains all information that was used to create the
// container. It may not be changed once created.
// It is stored, read-only, on disk